@@ -52,6 +52,10 @@ class Config:
         #
         # Options that apply to `px-subscribe` only
         #
+        parser.add_argument(
+            '--ws-ping-interval', type=float,
+            default=20.0,
+            help='WebSocket ping interval in seconds (float)')
         parser.add_argument(
             '--service', type=str,
             help='Service name')
@@ -64,9 +68,16 @@ class Config:
         parser.add_argument(
             '--subscribe-all', action='store_true',
             help='subscribe to ALL nodes discovered')
-        parser.add_argument(
+
+        # optionally select a subscriber that is not the default one
+        g = parser.add_mutually_exclusive_group()
+        g.add_argument(
+            '--connect-only', action='store_true',
+            help='connect to pxGrid brokers only, no subscription')
+        g.add_argument(
             '--session-dedup', action='store_true',
             help='run the sessionTopic de-duplicating subscriber')
+
         parser.add_argument(
             '--services', action='store_true',
             help='List out supported services')
@@ -104,8 +115,8 @@ class Config:
             '--get-anc-endpoints', action='store_true',
             help='Get endpoints with ANC policies')
         g.add_argument(
-            '--get-anc-endpoint-by-mac', action='store_true',
-            help='Get endpoints with ANC policy by MAC address')
+            '--get-anc-policy-by-mac', action='store_true',
+            help='Get endpoint\'s ANC policy by MAC address')
         g.add_argument(
             '--get-anc-policies', action='store_true',
             help='Get all ANC policies')
@@ -115,20 +126,28 @@ class Config:
         g.add_argument(
             '--apply-anc-policy-by-ip', action='store_true',
             help='Apply named ANC policy by endpoint IP address')
+        g.add_argument(
+            '--apply-anc-policy', action='store_true',
+            help='Apply named ANC policy by whatever parameters provided if there are enough')
         g.add_argument(
             '--clear-anc-policy-by-mac', action='store_true',
             help='Clear ANC policy by endpoint MAC address')
         g.add_argument(
             '--clear-anc-policy-by-ip', action='store_true',
-            help='Clear ANC policy by endpoint IP address')        
-        parser.add_argument(
-            '--mac-address', type=str,
-            help='Optional MAC address for ANC policies')
+            help='Clear ANC policy by endpoint IP address')
+
+        # anc parameters
         parser.add_argument(
             '--anc-policy', type=str,
             help='Optional ANC policy name')
         parser.add_argument(
-            '--nas-ip-address', type=str,
+            '--anc-mac-address', type=str,
+            help='Optional MAC address for ANC policies')
+        parser.add_argument(
+            '--anc-ip-address', type=str,
+            help='Optional IP address for ANC policies')
+        parser.add_argument(
+            '--anc-nas-ip-address', type=str,
             help='Optional NAS IP address for ANC policies')
 
         self.config = parser.parse_args()
@@ -141,10 +160,18 @@ class Config:
     def subscribe_all(self):
         return self.config.subscribe_all
 
+    @property
+    def connect_only(self):
+        return self.config.connect_only
+
     @property
     def session_dedup(self):
         return self.config.session_dedup
 
+    @property
+    def ws_ping_interval(self):
+        return self.config.ws_ping_interval
+
     @property
     def services(self):
         return self.config.services
@@ -209,14 +236,18 @@ class Config:
         return self.config.get_anc_endpoints
         
     @property
-    def get_anc_endpoint_by_mac(self):
-        return self.config.get_anc_endpoint_by_mac
+    def get_anc_policy_by_mac(self):
+        return self.config.get_anc_policy_by_mac
         
     @property
     def get_anc_policies(self):
         return self.config.get_anc_policies
         
     @property
+    def apply_anc_policy(self):
+        return self.config.apply_anc_policy
+        
+    @property 
     def apply_anc_policy_by_mac(self):
         return self.config.apply_anc_policy_by_mac
         
@@ -233,8 +264,8 @@ class Config:
         return self.config.clear_anc_policy_by_ip
         
     @property
-    def mac_address(self):
-        return self.config.mac_address
+    def anc_mac_address(self):
+        return self.config.anc_mac_address
 
     @property
     def anc_policy(self):
@@ -245,8 +276,8 @@ class Config:
         return self.config.anc_ip_address
 
     @property
-    def nas_ip_address(self):
-        return self.config.nas_ip_address
+    def anc_nas_ip_address(self):
+        return self.config.anc_nas_ip_address
 
     @property
     def description(self):
